% plotjrofk3: switching back to ksdensity from hist, and getting xscale back to linear. 
% note: plotjrofk.m used log scale and because of the scaling, the pdf will NOT
% look like a derivative of the CDF. If you are on a log scale, the slope
% of CDF for small k will be less steep than usual because the x-axis is stretched out
% and the slope of CDF for large k will be steeper than usual because the
% x-axis is shrunk. Hence, the pdf will NOT look like a derivative of CDF
% on a log scale (but it does not mean that you made a mistake when
% computing the pdf. The pdf is still the right one. It's just that the
% scaling is different). 
% Run plotjrofk3 to see pdf and CDF in a linear scale. 
% Run plotjrofk to see pdf and CDF in a log scale. 
% plotjrofk4: log scale and plotting is improved in accordance with
% plotjrofk_before_after

function y = plotjrofkminks(s, param)
% close all
color
% myk = sort(k(s, intparam)); % sort s so that pdf and cdf plots won't go back and forth. 
k = sort(kofs(s, param));
% Also, remove 0 from s so you can take a log. 

% for i = 1:2
%     myt(i, :) = num2str(i, '%d');
%     filenames(i, :) = strcat('jrofk_mse', myt(i, :));
% end
filenames(1, :) = 'jrofk_minks_pdf';
filenames(2, :) = 'jrofk_minks_cdf';

showfigure = [1 1];

if showfigure(1)
    figure(1)
    set(gcf,'defaultaxesfontsize', 13, 'DefaultAxesLineWidth', 1, 'DefaultAxesColorOrder', [rouge; vert; bfonce], ...
        'defaultlinelinewidth', 1, ...
        'defaultlinemarkersize', 10, ...
        'defaultlinemarker', 'none', ...
        'defaultaxesnextplot', 'add', ...
        'units', 'normalized', 'position', [ 0.3517    0.5200    0.2917    0.3889])
%         find ks density ===========
%             ks density estimation works for standardized data. Since log(s)
%             follows Gaussian, I'll take log of s first ...
            [emppdf, ki] = ksdensity(log(k), log(k));  % second log(k) is the points at which ksdensity is evaluated.
%             ... and then convert it back to linear scale 
            ki = exp(ki);
%         =================================
    myplot(1) = plot(ki, emppdf/max(emppdf)*max(pdfofk(s, param))); hold all  % NOTE!! do NOT write pdfofk(myk, estparam). pdfofk takes s and converts s into k by itself. 
                % rescale data above so it will match the estimated pdf
                % (pdfofs). These two are evaluated at two differenent sets
                % of s's. Plus, estimated pdf below is the derivative whereas
                % ksdensity above is produced from s. There is no guarantee that
                % they will match up in scale.  
    myplot(2) = plot(k, pdfofk(s, param)); % NOTE!! do NOT write pdfofk(myk, estparam). pdfofk takes s and converts s into k by itself. 
    set(myplot, 'marker', '.', 'markersize', 10, 'linewidth', 1)
    
    mylegend = legend('Data', 'Estimated PDF');
    set(mylegend, 'location', 'best', 'box', 'off')
    xlabel('Degree k')
    ylabel('PDF')
    
        grid on
        set(gca, 'xcolor', grisp, 'ycolor', grisp, 'zcolor', grisp, 'gridlinestyle', '-', 'minorgridlinestyle', '-')
        set(gca, 'xlim', [k(1) k(end)])
        set(gca, 'xscale', 'log')
        Caxes = copyobj(gca,gcf);
        set(Caxes, 'color', 'none', 'xcolor', noir, 'xgrid', 'off', 'ycolor', noir, 'ygrid','off')
end

if showfigure(2)
    figure(2)
    set(gcf,'defaultaxesfontsize', 13, 'DefaultAxesLineWidth', 1, 'DefaultAxesColorOrder', [rouge; vert; bfonce], ...
        'defaultlinelinewidth', 1, ...
        'defaultlinemarkersize', 10, ...
        'defaultlinemarker', 'none', ...
        'defaultaxesnextplot', 'add', ...        
        'units', 'normalized', 'position', [0.3517    0.0400    0.2917    0.3889]) 
%         'units', 'normalized', 'position', [0.65,0.515,0.291666666666667,0.388888888888889;]) to the right of fig(1)
    myplot(1) = plot(k, empcdf(k)); hold all
    myplot(2) = plot(k, cdfofk(s, param)); % NOTE!! do NOT write cdfofk(myk, estparam). cdfofk takes s and converts s into k by itself. 
    myplot(3) = plot(k, abs(empcdf(k) - cdfofk(s, param)));
    set(myplot, 'marker', '.')
   
    
    mylegend = legend('Data', 'Estimated CDF', 'Residual');
    set(mylegend, 'location', 'best', 'box', 'off')
    xlabel('Degree k')
    ylabel('CDF')
    
        grid on
        set(gca, 'xcolor', grisp, 'ycolor', grisp, 'zcolor', grisp, 'gridlinestyle', '-', 'minorgridlinestyle', '-')
        set(gca, 'xscale', 'log', 'xlim', [k(1) k(end)])
        Caxes = copyobj(gca,gcf);
        set(Caxes, 'color', 'none', 'xcolor', noir, 'xgrid', 'off', 'ycolor', noir, 'ygrid','off')
end

for i = 1:2   
    hgexport(figure(i), filenames(i, :))
end
    
end