function y = plotjrofs2(s, param)
% plotjrofs2.m: on 5/28/14. It uses pdfofs4 rather than pdfofs. pdfofs4 is
% computed step by step from cdf whereas pdfofs computes pdf analytically. 
% plotjrofs5.m: on 5/29/14. Swithced pdfofs2 to pdfofs5. 
% close all
color
s = sort(s); % sort s so that pdf and cdf plots won't go back and forth. 
% Also, remove 0 from s so you can take a log. 

% for i = 1:2
% %     myt(i, :) = num2str(i, '%d');
%     filenames(i, :) = strcat('jrofs_mse', myt(i, :));
% end
filenames(1, :) = 'jrofs_mse_pdf';
filenames(2, :) = 'jrofs_mse_cdf';

showfigure = [1 1];

if showfigure(1)
    figure(3)
    set(gcf,'defaultaxesfontsize', 13, 'DefaultAxesLineWidth', 1, 'DefaultAxesColorOrder', [rouge; rouge; vert; rouge; vert; vert], ...
        'defaultlinelinewidth', 2, ...
        'defaultlinemarkersize', 20, ...
        'defaultlinemarker', '.', ...
        'defaultaxesnextplot', 'add', ...
        'units', 'normalized', 'position', [0.65,0.515,0.291666666666667,0.388888888888889;])
%         find ks density ===========
%             ks density estimation works for standardized data. Since log(s)
%             follows Gaussian, I'll take log of s first ...
            [emppdf, si] = ksdensity(log(s), log(s));  % second log(s) to mark s at which ksdensity is evaluated
%             ... and then convert it back to linear scale 
            si = exp(si);
%         =================================
    monplot(1) = plot(si, emppdf/max(emppdf)*max(pdfofs4(s, param))); hold all
                % rescale data above so it will match the estimated pdf
                % (pdfofs). These two are evaluated at two differenent sets
                % of s's. Plus, estimated pdf below is the derivative whereas
                % ksdensity above is produced from s. There is no guarantee that
                % they will match up in scale.  
                temp = emppdf/max(emppdf)*max(pdfofs4(s, param));
    monplot(2) = plot(si(1), temp(1)); % this is for legend entry only. myplot(1) does dots and myplot(4) does a line. 
    monplot(3) = plot(s, pdfofs(s, param));
    
%         find ks density ===========
%             ks density estimation works for standardized data. Since log(s)
%             follows Gaussian, I'll take log of s first ...
            [emppdf, si] = ksdensity(log(s));
%             ... and then convert it back to linear scale 
            si = exp(si);
%         =================================
    monplot(4) = plot(si, emppdf/max(emppdf)*max(pdfofs4(s, param)));
    monplot(5) = plot(si, pdfofs_smooth(si, param));
    monplot(6) = plot(si(1), pdfofs_smooth(si(1), param)); % this is for legend entry only. monplot(3) does dots and monplot(5) does a line. 

    set(monplot(1), 'marker', '.', 'markersize', 12, 'line', 'none')
    set(monplot([2 6]), 'marker', '.', 'markersize', 12, 'line', '-', 'linewidth', 1)
    set(monplot(3), 'marker', '.', 'markersize', 12, 'line', 'none')
    set(monplot(4), 'marker', 'none', 'line', '-', 'linewidth', 1)
    set(monplot(5), 'marker', 'none', 'line', '-', 'linewidth', 1)
    
    mylegend = legend([monplot(2) monplot(6)], 'Data', 'Estimated PDF');
    set(mylegend, 'location', 'best', 'box', 'off')
    xlabel('City Size s')
    ylabel('PDF')
    
        grid on
        set(gca, 'xcolor', grisp, 'ycolor', grisp, 'zcolor', grisp, 'gridlinestyle', '-', 'minorgridlinestyle', '-')
        set(gca, 'xlim', [s(1)-1e-2 s(end)])
        set(gca, 'xscale', 'log')
        Caxes = copyobj(gca,gcf);
        set(Caxes, 'color', 'none', 'xcolor', noir, 'xgrid', 'off', 'ycolor', noir, 'ygrid','off')
end

if showfigure(2)
    figure(4)
    set(gcf,'defaultaxesfontsize', 13, 'DefaultAxesLineWidth', 1, 'DefaultAxesColorOrder', [rouge; vert; bfonce], ...
        'defaultlinelinewidth', 2, ...
        'defaultlinemarkersize', 10, ...
        'defaultlinemarker', '.', ...
        'defaultaxesnextplot', 'add', ...        
        'units', 'normalized', 'position', [0.65    0.04    0.291666666666667,0.388888888888889])
%         'units', 'normalized', 'position', [0.65,0.515,0.291666666666667,0.388888888888889;]) % to the right of fig(1)
%         'units', 'normalized', 'position', [0.354, 0.058,0.291666666666667,0.388888888888889;]) % in the middle
    myplot(1) = plot(s, empcdf(s)); hold all
    myplot(2) = plot(s, cdfofs(s, param));
    myplot(3) = plot(s, abs(empcdf(s) - cdfofs(s, param)));
    set(myplot, 'marker', '.', 'markersize', 6, 'linewidth', 1)
    
    mylegend = legend('Data', 'Estimated CDF', 'Residual');
    set(mylegend, 'location', 'east', 'box', 'off')
    xlabel('City Size s')
    ylabel('CDF')
    
        grid on
        set(gca, 'xcolor', grisp, 'ycolor', grisp, 'zcolor', grisp, 'gridlinestyle', '-', 'minorgridlinestyle', '-')
        set(gca, 'xscale', 'log', 'xlim', [s(1) s(end)])
        Caxes = copyobj(gca,gcf);
        set(Caxes, 'color', 'none', 'xcolor', noir, 'xgrid', 'off', 'ycolor', noir, 'ygrid','off')
end
for i = 1:2   
    hgexport(figure(i+2), filenames(i, :))
end
end