function y = geogap3(s, param)
% geogap3.m on 6/26/14: due to too many ties in 25K CDP data, geogap.m
% actually returns something larger than arith mean of 1/J. I'm trying to
% see what I can do to correct this theoretical impossibility. 

gamma   = param(1);
delta   = param(2);
knaught = param(3);
m       = param(4);
r       = param(5);

J = numel(s);

s = sort(s); % sort s in ascending order so we can take differential neighbor by neighbor

% Roadmap: Take the sum of the log of the following: 
% F(x_1) - F(x_0) = F(x_1) - 0
% F(x_2) - F(x_1)
% ...
% F(x_J) - F(x_J-1)
% F(x_J+1) - F(x_J) = 1 - F(x_J)

D = zeros(J+1, 1); % preallocation

% Note: You CANNOT define the gap elements by elements as below because
% cdfofs(s(i), param) is DIFFERENT from the ith entry of cdfofs(s, param). cdfofs needs
% to have s intact as an input because cdfofs calls J = numel(s) inside the
% function. And numel(s(1)) is just one. Not J. 
%     D(1) = log(cdfofs(s(1), param));
%     for i = 2:J
%         D(i) = log(cdfofs(s(i), param) - cdfofs(s(i-1), param));
%     end
%     D(J+1) = log(1 - cdfofs(s(J), param));
%
% So, I'm rewriting the gap format: 
F = cdfofs(s, param);
f = pdfofs(s, param);
D(1) = log(F(1));
for i = 2:J
    if s(i) == s(i-1)
        D(i) = log(f(i));
    else
        D(i) = log(F(i) - F(i-1));
    end
end
D(J+1) = log(1 - F(J));

y = sum(D(1:10000:J))/numel(1:10000:J);
    